@@ -2,13 +2,18 @@ use std::marker::PhantomData;
 
 use super::*;
 
-pub struct CollectState<T, E>(Vec<T>, PhantomData<E>);
+struct CollectState<T, E>(Vec<T>, PhantomData<E>);
+
+pub struct CollectResult<I, R> {
+    pub items: Vec<I>,
+    pub result: R,
+}
 
 impl<T, E> ScanFn for CollectState<T, E> {
     type InputItem = T;
     type InputResult = E;
     type OutputItem = ();
-    type OutputResult = (Vec<T>, Self::InputResult);
+    type OutputResult = CollectResult<T, Self::InputResult>;
 
     fn map_input(mut self, input: Self::InputItem) -> ScanState<Self> {
         self.0.push(input);
@@ -19,7 +24,7 @@ impl<T, E> ScanFn for CollectState<T, E> {
     }
 
     fn map_result(self, result: Self::InputResult) -> Self::OutputResult {
-        (self.0, result)
+        CollectResult { items: self.0, result }
     }
 }
 
@@ -28,7 +33,7 @@ where
     Self: ListFn,
     Self::End: ResultFn,
 {
-    fn collect(self) -> (Vec<Self::Item>, <Self::End as ResultFn>::Result) {
+    fn collect(self) -> CollectResult<Self::Item, <Self::End as ResultFn>::Result> {
         self.scan(CollectState(Vec::new(), PhantomData::default()))
             .fold()
     }
